@@ -1125,20 +1125,21 @@ about_cb (BonoboUIComponent *ui_container,
     "Hopefully, the users themselves",
     NULL
   };
-  static const gchar *license =
-    "This program is free software; you can redistribute it and/or modify\n"
-    "it under the terms of the GNU General Public License as published by\n"
-    "the Free Software Foundation; either version 2 of the License, or\n"
-    "(at your option) any later version.\n"
-    "\n"
-    "This program is distributed in the hope that it will be useful,\n"
-    "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-    "GNU General Public License for more details.\n"
-    "\n"
-    "You should have received a copy of the GNU General Public License\n"
-    "along with this program; if not, write to the Free Software\n"
-    "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n";
+  static const gchar *license[] = {
+    N_("The Fast User Switch Applet is free software; you can redistribute it and/or modify "
+       "it under the terms of the GNU General Public License as published by "
+       "the Free Software Foundation; either version 2 of the License, or "
+       "(at your option) any later version."),
+    N_("This program is distributed in the hope that it will be useful, "
+       "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+       "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+       "GNU General Public License for more details."),
+    N_("You should have received a copy of the GNU General Public License "
+       "along with this program; if not, write to the Free Software "
+        "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"),
+    NULL
+  };
+  gchar *license_i18n;
 
   if (about)
     {
@@ -1174,7 +1175,9 @@ about_cb (BonoboUIComponent *ui_container,
    */
   gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about),
 					   _("translator-credits"));
-  gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (about), license);
+  license_i18n = g_strjoinv ("\n\n", license);
+  gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (about), license_i18n);
+  g_free (license_i18n);
 
   g_object_add_weak_pointer (G_OBJECT (about),
 			     (gpointer *) &about);
@@ -2277,10 +2280,6 @@ static void
 maybe_lock_screen (FusaAppletData *adata,
 		   FusaDisplay    *display)
 {
-//  g_message ("Trying to lock screen, lock-key = %d, nested = %d.",
-//	     panel_applet_gconf_get_bool (adata->applet, LOCK_KEY, NULL),
-//	     fusa_display_get_nested (display));
-
   if (panel_applet_gconf_get_bool (adata->applet, LOCK_KEY, NULL) &&
       !fusa_display_get_nested (display))
     {
@@ -2290,14 +2289,11 @@ maybe_lock_screen (FusaAppletData *adata,
       gboolean use_gscreensaver = TRUE;
 
       args[0] = g_find_program_in_path ("gnome-screensaver-command");
-      g_message ("gnome-screensaver-command = `%s'", args[0]);
       if (!args[0])
         {
           args[0] = g_find_program_in_path ("xscreensaver-command");
-          g_message ("xscreensaver-command = `%s'", args[0]);
           use_gscreensaver = FALSE;
         }
-
       if (!args[0])
 	return;
 
@@ -2313,7 +2309,9 @@ maybe_lock_screen (FusaAppletData *adata,
 	screen = gdk_screen_get_default ();
 
       err = NULL;
-      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL, 0,
+      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL,
+				(G_SPAWN_STDERR_TO_DEV_NULL |
+				 G_SPAWN_STDOUT_TO_DEV_NULL),
 				NULL, NULL, NULL, &err))
 	{
 	  g_warning (_("Can't lock screen: %s"), err->message);
@@ -2325,7 +2323,9 @@ maybe_lock_screen (FusaAppletData *adata,
       else
 	args[1] = "-throttle";
 
-      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL, 0,
+      if (!gdk_spawn_on_screen (screen, g_get_home_dir (), args, NULL,
+				(G_SPAWN_STDERR_TO_DEV_NULL |
+				 G_SPAWN_STDOUT_TO_DEV_NULL),
 				NULL, NULL, NULL, &err))
 	{
 	  g_warning (_("Can't temporarily set screensaver to blank screen: %s"),
